@@ -14,7 +14,12 @@ class EltyerInitializer(AlgorithmContextInitializer):
     def initialize(self, algorithm: AlgorithmContext) -> None:
         client = Client()
         client.config.API_KEY = algorithm.config.get(constants.ELTYER_API_KEY)
-        client.start()
+
+        if algorithm.config.get_stateless():
+            client.start(notify_online=False)
+        else:
+            client.start()
+
         environment = client.get_environment()
 
         if environment is None:
@@ -22,4 +27,4 @@ class EltyerInitializer(AlgorithmContextInitializer):
                 "Could not retrieve algorithm environment from ELTYER"
             )
 
-        algorithm.config.set(constants.ELTYER_CLIENT, client)
+        algorithm.config.add(constants.ELTYER_CLIENT, client)
