@@ -1,5 +1,6 @@
 from investing_algorithm_framework import App
-
+from eltyer_investing_algorithm_framework.exceptions \
+    import EltyerInvestingAlgorithmFrameworkException
 from eltyer_investing_algorithm_framework.configuration import constants
 from eltyer_investing_algorithm_framework.initializer import EltyerInitializer
 from eltyer_investing_algorithm_framework.order_executor import \
@@ -8,15 +9,15 @@ from eltyer_investing_algorithm_framework.portfolio_manager import \
     EltyerPortfolioManager
 
 
-def create_app(resources_directory, config={}, trading_bot_api_key=None):
-    app = App(
-        resources_directory=resources_directory,
-        config=config
-    )
+def create_app(resource_directory, config={}, key=None):
 
-    if trading_bot_api_key is not None:
-        app.config[constants.ELTYER_API_KEY] = trading_bot_api_key
+    if key is None:
+        raise EltyerInvestingAlgorithmFrameworkException(
+            "Algorithm api key not provided"
+        )
 
+    config[constants.ELTYER_API_KEY] = key
+    app = App(resource_directory=resource_directory, config=config)
     app.add_initializer(EltyerInitializer)
     app.add_order_executor(EltyerOrderExecutor)
     app.add_portfolio_manager(EltyerPortfolioManager)
